==> italian_2_7_0.zip: italian_2_7_0/language/it/app.php <==
<?php
/**
*
* This file is part of the phpBB Forum Software package.
*
* @copyright (c) phpBB Limited <https://www.phpbb.com>
* @copyright (c) 2010 phpBB.it
* @copyright (c) 2014 phpBBItalia.net <http://www.phpbbitalia.net>
* @license GNU General Public License, version 2 (GPL-2.0)
*
* For full copyright and license information, please see
* the docs/CREDITS.txt file.
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
//
// Some characters you may want to copy&paste:
// ’ » “ ” …
//

$lang = array_merge($lang, array(
	'CONTROLLER_ARGUMENT_VALUE_MISSING'	=> 'Valore mancante per l’argomento #%1$s: <strong>%3$s</strong> nella classe <strong>%2$s</strong>',
	'CONTROLLER_NOT_SPECIFIED'			=> 'Nessun controller è stato specificato.',
	'CONTROLLER_METHOD_NOT_SPECIFIED'	=> 'Nessun metodo specificato per il controller.',
	'CONTROLLER_SERVICE_UNDEFINED'		=> 'Il servizio per il controller "<strong>%s</strong>" non è definito in ./config/services.yml.',
));

==> italian_2_8_0.zip: italian_2_8_0/language/it/app.php <==
<?php
/**
*
* This file is part of the phpBB Forum Software package.
*
* @copyright (c) phpBB Limited <https://www.phpbb.com>
* @copyright (c) 2010 phpBB.it
* @copyright (c) 2014 phpBBItalia.net <http://www.phpbbitalia.net>
* @license GNU General Public License, version 2 (GPL-2.0)
*
* For full copyright and license information, please see
* the docs/CREDITS.txt file.
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
//
// Some characters you may want to copy&paste:
// ’ » “ ” …
//

$lang = array_merge($lang, array(
	'CONTROLLER_ARGUMENT_VALUE_MISSING'	=> 'Valore mancante per l’argomento #%1$s: <strong>%3$s</strong> nella classe <strong>%2$s</strong>',
	'CONTROLLER_NOT_SPECIFIED'			=> 'Nessun controller è stato specificato.',
	'CONTROLLER_METHOD_NOT_SPECIFIED'	=> 'Nessun metodo specificato per il controller.',
	'CONTROLLER_SERVICE_UNDEFINED'		=> 'Il servizio per il controller “<strong>%s</strong>” non è definito in ./config/services.yml.',
));
